@@ -576,10 +576,8 @@ class AsyncLoadingApiClient:
                     working_page = current_page
                     current_page *= 2
 
-            # Check the page in the middle of highest known working page and
-            # current page until they have the same page number.
             while True:
-                page = working_page + (current_page - working_page) / 2
+                page = working_page + math.floor((current_page - working_page) / 2)
                 headers["page"] = str(page)
 
                 async with session.get(url, headers=headers) as response:
@@ -590,9 +588,13 @@ class AsyncLoadingApiClient:
                     else:
                         current_page = page
 
-                    if math.floor(current_page) == math.floor(working_page):
+                    if current_page - 1 == working_page:
                         break
 
-        total_pages = math.floor(working_page)
+        total_pages = working_page
 
-        return total_pages
+        return {
+            "code": 200,
+            "message": "OK",
+            "data": {"total_pages": total_pages},
+        }
